# python-ssh

[![PythonSSH Version](https://img.shields.io/pypi/v/python-ssh?style=for-the-badge)](https://pypi.org/project/python-ssh/)
[![PythonSSH Status](https://img.shields.io/pypi/status/python-ssh?style=for-the-badge)](https://pypi.org/project/python-ssh)
[![PythonSSH Python Versions](https://img.shields.io/pypi/pyversions/python-ssh?style=for-the-badge)](https://pypi.org/project/python-ssh/)
[![PythonSSH Release](https://img.shields.io/github/release/degagne/python-ssh?style=for-the-badge)](https://github.com/degagne/python-ssh/releases/)
[![PythonSSH License](https://img.shields.io/github/license/degagne/python-ssh?style=for-the-badge)](https://github.com/degagne/python-ssh/blob/master/LICENSE)

**python-ssh** provides a convenient interface used to execute commands on remote hosts. The following documentation provides an overview of how to use the interface.

## Installation

It's recommended to be installed using [pip](https://pip.pypa.io/en/stable/).

```bash
pip install python-ssh
```

Releases are listed on the [Releases](https://github.com/degagne/python-ssh/releases) page.

## Documentation

For documentation, please visit [python-ssh](https://python-ssh.readthedocs.io/en/latest/index.html).

## License

`python-ssh` is licensed under MIT license. See the [LICENSE](https://github.com/degagne/python-ssh/blob/master/LICENSE) for more information.